@@ -1,8 +1,11 @@
+import sys
+import os
+
 def oxygen_install():
     print("Downloading Nitrogen (installer for Oxygen)...")
     import urllib.request
     urllib.request.urlretrieve("https://raw.githubusercontent.com/arjunj132/oxygen/main/nitrogen.py", "nitrogen.py")
-    exec(open("nitrogen.py").read())
+    os.system(sys.executable + " nitrogen.py")
 
 def oxygen_run():
-    exec(open("nitrogen.py").read())
\ No newline at end of file
+    os.system(sys.executable + " nitrogen.py")
\ No newline at end of file
